summaryrefslogtreecommitdiffstats
path: root/korganizer/koagenda.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/koagenda.cpp')
-rw-r--r--korganizer/koagenda.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/korganizer/koagenda.cpp b/korganizer/koagenda.cpp
index bc456a78..a0aaddbc 100644
--- a/korganizer/koagenda.cpp
+++ b/korganizer/koagenda.cpp
@@ -73,7 +73,7 @@ MarcusBains::MarcusBains(KOAgenda *_agenda,const char *name )
minutes->start(0, true);
mTimeBox = new TQLabel(this);
- mTimeBox->setAlignment(Qt::AlignRight | Qt::AlignBottom);
+ mTimeBox->tqsetAlignment(Qt::AlignRight | Qt::AlignBottom);
TQPalette pal = mTimeBox->palette();
pal.setColor(TQColorGroup::Foreground, Qt::red);
mTimeBox->setPalette(pal);
@@ -92,13 +92,13 @@ MarcusBains::~MarcusBains()
int MarcusBains::todayColumn()
{
- TQDate currentDate = TQDate::currentDate();
+ TQDate tqcurrentDate = TQDate::tqcurrentDate();
DateList dateList = agenda->dateList();
DateList::ConstIterator it;
int col = 0;
for(it = dateList.begin(); it != dateList.end(); ++it) {
- if((*it) == currentDate)
+ if((*it) == tqcurrentDate)
return KOGlobals::self()->reverseLayout() ?
agenda->columns() - 1 - col : col;
++col;
@@ -296,7 +296,7 @@ void KOAgenda::init()
setMinimumSize( 30, int( mGridSpacingY + 1 ) );
// setMaximumHeight(mGridSpacingY * mRows + 5);
- // Disable horizontal scrollbar. This is a hack. The geometry should be
+ // Disable horizontal scrollbar. This is a hack. The tqgeometry should be
// controlled in a way that the contents horizontally always fits. Then it is
// not necessary to turn off the scrollbar.
setHScrollBarMode( AlwaysOff );
@@ -1276,7 +1276,7 @@ void KOAgenda::placeAgendaItem( KOAgendaItem *item, double subCellWidth )
// kdDebug(5850) << "KOAgenda::placeAgendaItem(): " << item->incidence()->summary()
// << " subCellWidth: " << subCellWidth << endl;
- // "left" upper corner, no subcells yet, RTL layouts have right/left switched, widths are negative then
+ // "left" upper corner, no subcells yet, RTL tqlayouts have right/left switched, widths are negative then
TQPoint pt = gridToContents( TQPoint( item->cellXLeft(), item->cellYTop() ) );
// right lower corner
TQPoint pt1 = gridToContents( TQPoint( item->cellXLeft() + item->cellWidth(),
@@ -1300,11 +1300,11 @@ void KOAgenda::placeAgendaItem( KOAgendaItem *item, double subCellWidth )
xpos = pt.x() + int( subCellPos );
ypos = pt.y();
}
- if ( KOGlobals::self()->reverseLayout() ) { // RTL language/layout
+ if ( KOGlobals::self()->reverseLayout() ) { // RTL language/tqlayout
xpos += width;
width = -width;
}
- if ( height<0 ) { // BTT (bottom-to-top) layout ?!?
+ if ( height<0 ) { // BTT (bottom-to-top) tqlayout ?!?
ypos += height;
height = -height;
}
@@ -1393,7 +1393,7 @@ void KOAgenda::drawContents(TQPainter* p, int cx, int cy, int cw, int ch)
if ( pt2.x() >= pt1.x() /*&& pt2.y() >= pt1.y()*/) {
int gxStart = contentsToGrid( pt1 ).x();
int gxEnd = contentsToGrid( pt2 ).x();
- // correct start/end for rtl layouts
+ // correct start/end for rtl tqlayouts
if ( gxStart > gxEnd ) {
int tmp = gxStart;
gxStart = gxEnd;
@@ -1419,7 +1419,7 @@ void KOAgenda::drawContents(TQPainter* p, int cx, int cy, int cw, int ch)
}
}
} else {
// last entry in holiday mask denotes the previous day not visible (needed for overnight shifts)
if ( gxStart < int(mHolidayMask->count()-1) && !mHolidayMask->at(gxStart)) {
dbp.fillRect( xStart, pt1.y(), xWidth, pt2.y() - pt1.y() + 1,
KOPrefs::instance()->mWorkingHoursColor );
@@ -1769,7 +1769,7 @@ void KOAgenda::showAgendaItem( KOAgendaItem *agendaItem )
agendaItem->hide();
addChild( agendaItem );
- if ( !mItems.containsRef( agendaItem ) ) {
+ if ( !mItems.tqcontainsRef( agendaItem ) ) {
mItems.append( agendaItem );
}
placeSubCells( agendaItem );
@@ -2038,9 +2038,9 @@ void KOAgenda::setDateList(const DateList &selectedDates)
marcus_bains();
}
-void KOAgenda::setHolidayMask(TQMemArray<bool> *mask)
+void KOAgenda::setHolidayMask(TQMemArray<bool> *tqmask)
{
- mHolidayMask = mask;
+ mHolidayMask = tqmask;
}
@@ -1419,7 +1419,7 @@ void KOAgenda::drawContents(TQPainter* p, int cx, int cy, int cw, int ch)
}
} else {
- // last entry in holiday mask denotes the previous day not visible (needed for overnight shifts)
+ // last entry in holiday tqmask denotes the previous day not visible (needed for overnight shifts)
if ( gxStart < int(mHolidayMask->count()-1) && !mHolidayMask->at(gxStart)) {
dbp.fillRect( xStart, pt1.y(), xWidth, pt2.y() - pt1.y() + 1,